% Matlab script to create a Generic Cluster profile using Slurm
% 
% This version of configCluster is for use on a workstation outside
% the HPC cluster, to send to the HPC  cluster
%
% Author: Tom Payerle (payerle@umd.edu) 
% (c) University of Maryland 2022-2023

function cluster = configCluster(Args)
    arguments
        % These arguments should match configClusterCommon
	% but we change some defaults
	%
        % useLocalCluster: default to false
        Args.useLocalCluster (1,1) logical = logical(0)
        % interactive: default to true
        Args.interactive (1,1) logical = logical(1)
        % clusterName: name of cluster to submit jobs to
        Args.clusterName = []
        % allowUnknownMatlab: if set, we will try to create profile for
        %       a Matlab version not in our list of known MATLAB versions
        %       for this cluster.  
        Args.allowUnknownMatlab  = []
        % username on cluster.  Defaults to username on current system
        Args.clusterUsername = []
        % location of plugin scripts.  If useLocalCluster is set, will 
        % default to /software/matlab/parallel_slurm/current.  Otherwise,
        % defaults to  Documents/MATLKAB/SupportPackages/$MATLAB_VERSION 
        % under home directory.  
        Args.pluginScriptDir = []
        % remoteJobStorageLocation.
        % Defaults from cluster infomation
        Args.remoteJobStorageLocation = []
        % name to use for the profile
        % Defaults to 'Clustername HPC'
        Args.profileName = []
        % Require confirmation.  Ignored unless interactive is also set
        Args.requireConfirmation (1,1) logical = logical(1)
    end

    errorIDroot = 'UMD:GenericSlurm:Parallel:configCluster:';

    cluster = configClusterCommon( ...
        useLocalCluster = Args.useLocalCluster, ...
        interactive = Args.interactive, ...
        clusterName = Args.clusterName, ...
        allowUnknownMatlab = Args.allowUnknownMatlab, ...
        clusterUsername = Args.clusterUsername, ...
        pluginScriptDir = Args.pluginScriptDir, ...
        remoteJobStorageLocation = Args.remoteJobStorageLocation, ...
        profileName = Args.profileName, ...
        requireConfirmation = Args.requireConfirmation ...
    );
end








